@@ -31,6 +31,8 @@ sub new
     $this->{WORDS} = [];
     $this->{OUTPUTS} = ();
     $this->setName;
+
+
     $this->setOutputFiles($option_set,$message_set);
     return $this;
 }
@@ -752,7 +754,7 @@ sub setOutputFiles
 	'TC-for-BioLG'=>'xml:TCforBioLG.xml',
 	'termList'=>'raw:termList.txt',
 	'printChunking'=>'html:candidatesAndUnparsedInCorpus.html',
-	'debug'=>'raw:debug,unparsable',
+	'debug'=>'raw:debug,unparsable,unparsed',
 	'TTG-style-term-candidates' => 'raw:termCandidates.ttg',
 	'XML-corpus-for-BioLG' => 'xml:corpusForBioLG.xml'
 	);
@@ -1264,3 +1266,193 @@ sub getWords
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Lingua::YaTeA::Corpus - Perl extension for ???
+
+=head1 SYNOPSIS
+
+  use Lingua::YaTeA::Corpus;
+  Lingua::YaTeA::Corpus->();
+
+=head1 DESCRIPTION
+
+
+=head1 METHODS
+
+
+=head2 new()
+
+
+=head2 preLoadLexicon()
+
+
+=head2 read()
+
+
+=head2 recordWords()
+
+
+=head2 addWordFromCorpus()
+
+
+=head2 incrementCounters()
+
+
+=head2 print()
+
+
+=head2 selectTestifiedTerms()
+
+
+=head2 MarkTestifiedTerms()
+
+
+=head2 createAnnotation()
+
+
+=head2 MarkForbiddenStructures()
+
+
+=head2 WrapBlock()
+
+
+=head2 UnwrapBlock()
+
+
+=head2 chunk()
+
+
+=head2 cleanChunk()
+
+
+=head2 deleteAnnotationMarks()
+
+
+=head2 pruneFromStart()
+
+
+=head2 pruneFromEnd()
+
+
+=head2 checkCompulsory()
+
+
+=head2 getWord()
+
+
+=head2 size()
+
+
+=head2 expandStartTriggers()
+
+
+=head2 expandEndTriggers()
+
+
+=head2 getSentenceSet()
+
+
+=head2 getDocumentSet()
+
+
+=head2 getFileHandle()
+
+
+=head2 getPath()
+
+
+=head2 getName()
+
+
+=head2 getOutputFileSet()
+
+
+=head2 getLexicon()
+
+
+=head2 setName()
+
+
+=head2 setOutputFiles()
+
+
+=head2 setFilesForOption()
+
+
+=head2 printCorpusForLGPwithTCs()
+
+
+=head2 printCorpusForLGPwithTTs()
+
+
+=head2 getBestOccurrences()
+
+
+=head2 removeOccurrence()
+
+
+=head2 printCorpusForBioLG{()
+
+
+=head2 printXMLcorpus()
+
+
+=head2 printXMLheader()
+
+
+=head2 printXMLtrailer()
+
+
+=head2 loadLGPmappingFile()
+
+
+=head2 printCandidatesAndUnparsedInCorpus()
+
+
+=head2 printHTMLheader()
+
+
+=head2 printHTMLtrailer()
+
+
+=head2 printHTMLCorpus()
+
+
+=head2 setColor()
+
+
+=head2 orderOccurrencesForXML()
+
+
+=head2 orderOccurrences()
+
+
+=head2 getWords()
+
+
+=head1 SEE ALSO
+
+Sophie Aubin and Thierry Hamon. Improving Term Extraction with
+Terminological Resources. In Advances in Natural Language Processing
+(5th International Conference on NLP, FinTAL 2006). pages
+380-387. Tapio Salakoski, Filip Ginter, Sampo Pyysalo, Tapio Pahikkala
+(Eds). August 2006. LNAI 4139.
+
+
+=head1 AUTHOR
+
+Thierry Hamon <thierry.hamon@lipn.univ-paris13.fr> and Sophie Aubin <sophie.aubin@lipn.univ-paris13.fr>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2005 by Thierry Hamon and Sophie Aubin
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.6 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
